@@ -21,11 +21,12 @@ use crate::{
         XATTR_SIZE_MAX,
     },
     config::ROOT_FILE,
-    fs::{denyxattr, filterxattr, FsFlags},
     kernel::{syscall_path_handler, to_atflags},
+    lookup::FsFlags,
     path::XPath,
     req::{PathArgs, SysArg, SysFlags, UNotifyEventRequest},
     sandbox::SandboxGuard,
+    xattr::{denyxattr, filterxattr},
 };
 
 pub(crate) fn sys_getxattr(request: UNotifyEventRequest) -> ScmpNotifResp {
@@ -716,7 +717,7 @@ fn syscall_getxattrat_handler(
     let mut args = MaybeUninit::<XattrArgs>::uninit();
 
     // SAFETY: Ensure size of XattrArgs matches with user argument.
-    if req.data.args[5] != std::mem::size_of::<XattrArgs>() as u64 {
+    if req.data.args[5] != size_of::<XattrArgs>() as u64 {
         return Err(Errno::EINVAL);
     }
 
@@ -724,10 +725,7 @@ fn syscall_getxattrat_handler(
     // We don't read uninitialized memory, and after `read_mem` fills it,
     // we're good to assume it's valid.
     let buf = unsafe {
-        std::slice::from_raw_parts_mut(
-            args.as_mut_ptr().cast::<u8>(),
-            std::mem::size_of::<XattrArgs>(),
-        )
+        std::slice::from_raw_parts_mut(args.as_mut_ptr().cast::<u8>(), size_of::<XattrArgs>())
     };
 
     // Read the remote data structure.
@@ -887,7 +885,7 @@ fn syscall_setxattrat_handler(
     let mut args = MaybeUninit::<XattrArgs>::uninit();
 
     // SAFETY: Ensure size of XattrArgs matches with user argument.
-    if req.data.args[5] != std::mem::size_of::<XattrArgs>() as u64 {
+    if req.data.args[5] != size_of::<XattrArgs>() as u64 {
         return Err(Errno::EINVAL);
     }
 
@@ -895,10 +893,7 @@ fn syscall_setxattrat_handler(
     // We don't read uninitialized memory, and after `read_mem` fills it,
     // we're good to assume it's valid.
     let buf = unsafe {
-        std::slice::from_raw_parts_mut(
-            args.as_mut_ptr().cast::<u8>(),
-            std::mem::size_of::<XattrArgs>(),
-        )
+        std::slice::from_raw_parts_mut(args.as_mut_ptr().cast::<u8>(), size_of::<XattrArgs>())
     };
 
     // Read the remote data structure.
